@@ -1,7 +1,6 @@
 import json
 
 import pytest
-from funcy import first  # type: ignore
 
 from dvc_render.vega import BadTemplateError, VegaRenderer
 from dvc_render.vega_templates import NoFieldInDataError, Template
@@ -38,6 +37,21 @@ def test_init_empty():
     assert renderer.generate_markdown("foo") == ""
 
 
+def test_default_template_mark():
+    datapoints = [
+        {"first_val": 100, "second_val": 100, "val": 2},
+        {"first_val": 200, "second_val": 300, "val": 3},
+    ]
+
+    plot_content = json.loads(VegaRenderer(datapoints, "foo").partial_html())
+
+    assert plot_content["mark"] == {
+        "type": "line",
+        "point": True,
+        "tooltip": {"content": "data"},
+    }
+
+
 def test_choose_axes():
     props = {"x": "first_val", "y": "second_val"}
     datapoints = [
@@ -61,12 +75,8 @@ def test_choose_axes():
             "second_val": 300,
         },
     ]
-    assert (
-        first(plot_content["layer"])["encoding"]["x"]["field"] == "first_val"
-    )
-    assert (
-        first(plot_content["layer"])["encoding"]["y"]["field"] == "second_val"
-    )
+    assert plot_content["encoding"]["x"]["field"] == "first_val"
+    assert plot_content["encoding"]["y"]["field"] == "second_val"
 
 
 def test_confusion():
